package com.ynet.life.net.upload;

import com.ynet.gene.core.GENEException;
import com.ynet.gene.web.multipart.GENEMultipartHttpServletRequest;
import com.ynet.gene.web.multipart.MultipartHttpServletRequest;
import com.ynet.gene.web.multipart.MultipartResolver;
import com.ynet.gene.web.multipart.UploadStatusListener;
import com.ynet.gene.web.multipart.implement.GENEMultipartFile;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.exception.UploadFileFailedException;
import com.ynet.life.file.LifeFile;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Random;
import javax.servlet.http.HttpServletRequest;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadBase;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;

/* loaded from: com_ynet_life_net_upload.jar:com/ynet/life/net/upload/LifeMultipartResolver.class */
public class LifeMultipartResolver implements MultipartResolver {
    private long maxFileSize = 512000;
    private int bufferSize = 10240;
    private String tempFileRootPath = null;
    private String uploadFileRootPath = null;
    private Map mvcMap = new HashMap();
    private String filePathField = null;

    public void setFilePathField(String filePathField) {
        this.filePathField = filePathField;
    }

    public void addUploadFileMvc(UploadFileMvc mvc) {
        this.mvcMap.put(mvc.id, mvc);
    }

    public boolean isMultipart(HttpServletRequest request) {
        return ServletFileUpload.isMultipartContent(request);
    }

    public MultipartHttpServletRequest resolverMultipart(HttpServletRequest request, UploadStatusListener listener) throws GENEException {
        String mvcName = getMvcName(request);
        UploadFileMvc mvc = (UploadFileMvc) this.mvcMap.get(mvcName);
        if (mvc == null) {
            Trace.logError("LifeFile", String.valueOf(mvcName) + "没有文件上传权限");
            throw new TranFailException("EBLN0000", String.valueOf(mvcName) + "没有文件上传权限");
        }
        DiskFileItemFactory factory = new DiskFileItemFactory(this.bufferSize, new File(this.tempFileRootPath));
        ServletFileUpload upload = new ServletFileUpload(factory);
        upload.setSizeMax(getMaxFileSize(mvc));
        try {
            List<FileItem> items = upload.parseRequest(request);
            Map parameters = new HashMap();
            Map fileMap = new HashMap();
            String str = null;
            for (FileItem item : items) {
                String fieldName = item.getFieldName();
                if (!item.isFormField()) {
                    String originalFileName = item.getName();
                    if (originalFileName.length() > 0) {
                        mvc.validateType(item);
                        String uploadPath = getUploadDirectory(originalFileName);
                        if (!new File(uploadPath).isDirectory()) {
                            new File(uploadPath).mkdir();
                        }
                        String finalFileName = getFileName(originalFileName);
                        String finalFilePathName = String.valueOf(uploadPath) + finalFileName;
                        str = finalFilePathName.substring(finalFilePathName.indexOf(this.uploadFileRootPath.length()) + this.uploadFileRootPath.length());
                        File uploadedFile = new File(finalFilePathName);
                        try {
                            item.write(uploadedFile);
                            Trace.logDebug("LifeFile", "文件[" + finalFilePathName + "]上传成功");
                            fileMap.put(fieldName, new GENEMultipartFile(fieldName, finalFilePathName, originalFileName));
                            addParameter(fieldName, originalFileName, parameters);
                        } catch (Exception ex) {
                            Trace.logError("LifeFile", "文件[" + finalFilePathName + "]上传失败", ex);
                            throw new TranFailException("EBLN0000", "文件[" + finalFilePathName + "]上传失败", ex);
                        }
                    }
                }
                if (item.isFormField()) {
                    try {
                        String fieldValue = item.getString("UTF-8");
                        addParameter(fieldName, fieldValue, parameters);
                    } catch (UnsupportedEncodingException e) {
                        Trace.logWarning("LifeFile", "不支持的编码", e);
                    }
                }
            }
            if (str != null && str.length() > 0) {
                addParameter(this.filePathField, str, parameters);
            }
            return new GENEMultipartHttpServletRequest(request, parameters, fileMap);
        } catch (FileUploadException ex2) {
            Trace.logError("LifeFile", "文件上传请求处理失败", ex2);
            throw new TranFailException("EBLN0000", "文件上传请求处理失败", ex2);
        } catch (FileUploadBase.SizeLimitExceededException ex3) {
            Trace.logError("LifeFile", "文件上传大小超过[" + getMaxFileSize(mvc) + " Bytes]限制", ex3);
            throw new UploadFileFailedException("文件上传大小超过[" + getMaxFileSize(mvc) + " Bytes]限制");
        }
    }

    public void cleanup(MultipartHttpServletRequest request) {
    }

    private String getMvcName(HttpServletRequest request) {
        String reqURI = request.getRequestURI();
        String contextPath = request.getContextPath();
        return reqURI.substring(contextPath.length() + 1);
    }

    private long getMaxFileSize(UploadFileMvc mvc) {
        long mvcMaxSize = mvc.maxFileSize;
        return mvcMaxSize > 0 ? mvcMaxSize : this.maxFileSize;
    }

    private void checkFolder(String folderPath) {
        if (!new File(folderPath).isDirectory()) {
            Trace.logError("LifeFile", "本地目录--->" + folderPath + " 不可用");
            LifeFile.makeMultiDirectory(folderPath);
        }
    }

    private void addParameter(String key, String value, Map map) {
        Object preValueObj = map.get(key);
        if (preValueObj == null) {
            map.put(key, new String[]{value});
            return;
        }
        int len = ((String[]) preValueObj).length;
        String[] sArr = new String[len + 1];
        System.arraycopy(preValueObj, 0, sArr, 0, len);
        sArr[len] = value.trim();
        map.put(key, sArr);
    }

    protected String getUploadDirectory(String fileName) {
        return String.valueOf(this.uploadFileRootPath) + LifeStandard.getServerTime("yyyyMMdd") + LifeFile.DIR_SEPARATOR;
    }

    protected String getFileName(String fileName) {
        String generateName = String.valueOf(LifeStandard.getServerTime("HHmmssSSS")) + new Random().nextInt(1000);
        int dotPos = fileName.lastIndexOf(".");
        if (dotPos > 0) {
            return String.valueOf(generateName) + fileName.substring(dotPos);
        }
        return generateName;
    }

    public void setMaxFileSize(String maxFileSize) {
        this.maxFileSize = Long.parseLong(maxFileSize);
    }

    public void setBufferSize(String bufferSize) {
        this.bufferSize = Integer.parseInt(bufferSize);
    }

    public void setTempFileRootPath(String tempFileRootPath) {
        this.tempFileRootPath = tempFileRootPath;
        checkFolder(this.tempFileRootPath);
    }

    public void setUploadFileRootPath(String uploadFileRootPath) {
        if (uploadFileRootPath.endsWith(LifeFile.DIR_SEPARATOR)) {
            this.uploadFileRootPath = uploadFileRootPath;
        } else {
            this.uploadFileRootPath = String.valueOf(uploadFileRootPath) + LifeFile.DIR_SEPARATOR;
        }
        checkFolder(this.uploadFileRootPath);
    }
}
